<p align="center">
  tinyweather
</p>

---------------------------

Software for a home weather station.

Tinyweather's main use case is to gather data from climate sensors in an easy to understand format that the user can then play with and analyze.

We will have libraries for rain gauges and BME280/680s.

Tinyweather is maintained by the author of this document.

### Installation

```bash
git clone 
```

### Contribution

We are happy to have users contribute, however, in the early stages, the author will take a largely dictatorial approach to the software design.

### Scripts

Put custom built scripts in this directory. There are two scripts that gather climate data from the USDA and plot SWE and rain accumulation. These are examples of the flavors of scripts that should be added.
